@@ -3,6 +3,8 @@ package Fey::Role::SQL::HasWhereClause;
 use strict;
 use warnings;
 
+our $VERSION = '0.33';
+
 use Fey::Exceptions qw( param_error );
 
 use Fey::SQL::Fragment::Where::Boolean;
@@ -13,15 +15,16 @@ use Fey::SQL::Fragment::Where::SubgroupEnd;
 use Moose::Role;
 
 has '_where' =>
-    ( metaclass => 'Collection::Array',
-      is        => 'ro',
-      isa       => 'ArrayRef',
-      default   => sub { [] },
-      provides  => { push  => '_add_where_element',
-                     empty => '_has_where_elements',
-                     last  => '_last_where_element',
-                   },
-      init_arg  => undef,
+    ( traits   => [ 'Array' ],
+      is       => 'bare',
+      isa      => 'ArrayRef',
+      default  => sub { [] },
+      handles  => { _add_where_element  => 'push',
+                    _has_where_elements => 'count',
+                    _last_where_element => [ 'get', -1 ],
+                    _where              => 'elements',
+                  },
+      init_arg => undef,
     );
 
 
@@ -158,7 +161,7 @@ sub where_clause
     return ( $sql
              . ( join ' ',
                  map { $_->sql($dbh) }
-                 @{ $self->_where() }
+                 $self->_where()
                )
            );
 }
@@ -170,7 +173,7 @@ sub bind_params
     return
         ( map { $_->bind_params() }
           grep { $_->can('bind_params') }
-          @{ $self->_where() }
+          $self->_where()
         );
 }
 
