@@ -3,6 +3,8 @@ package Fey::Schema;
 use strict;
 use warnings;
 
+our $VERSION = '0.33';
+
 use Fey::Exceptions qw( param_error );
 use Fey::NamedObjectSet;
 use Fey::SQL;
@@ -10,7 +12,7 @@ use Fey::Table;
 use Fey::Types;
 use Scalar::Util qw( blessed );
 
-use Moose;
+use Moose 0.90;
 use MooseX::Params::Validate qw( pos_validated_list );
 use MooseX::SemiAffordanceAccessor;
 use MooseX::StrictConstructor;
