@@ -3,12 +3,13 @@ package Fey::Table::Alias;
 use strict;
 use warnings;
 
+our $VERSION = '0.33';
+
 use Fey::Exceptions qw(param_error);
 use Fey::Table;
 use Fey::Types;
 
 use Moose;
-use MooseX::AttributeHelpers;
 use MooseX::Params::Validate qw( pos_validated_list );
 use MooseX::SemiAffordanceAccessor;
 use MooseX::StrictConstructor;
@@ -34,15 +35,15 @@ has 'alias_name' =>
     );
 
 has '_columns' =>
-    ( metaclass => 'Collection::Hash',
-      is        => 'ro',
-      isa       => 'HashRef[Fey::Column]',
-      default   => sub { {} },
-      provides  => { 'get'    => '_get_column',
-                     'set'    => '_set_column',
-                     'exists' => '_has_column',
-                   },
-      init_arg  => undef,
+    ( traits   => [ 'Hash' ],
+      is       => 'bare',
+      isa      => 'HashRef[Fey::Column]',
+      default  => sub { {} },
+      handles  => { _get_column => 'get',
+                    _set_column => 'set',
+                    _has_column => 'exists',
+                  },
+      init_arg => undef,
     );
 
 with 'Fey::Role::Named';
